pub struct Hasher<F, Digest, H, C> { /* private fields */ }Expand description
MerkleHasher implementation built from a cryptographic hash function and a compression function. This struct is intended for use by the protocol verifier. Prover backends may use independent but functionally equivalent implementations.
The compression function does not need to be collision-resistant and only needs to be a pseudo-cryptographic function: https://eprint.iacr.org/2026/089.
Implementations